@@ -160,15 +160,12 @@ def save_df_as_csv(
             destination = filename
         else:
             destination = os.path.join(path, filename)
-            logger.info("Saving {}".format(os.path.relpath(destination)))
+            logger.info(f"Saving {os.path.relpath(destination)}")
 
         if prepend_info:
             s = (
-                "# Generated by snps v{}, https://pypi.org/project/snps/\n"
-                "# Generated at {} UTC\n".format(
-                    snps.__version__,
-                    datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S"),
-                )
+                f"# Generated by snps v{snps.__version__}, https://pypi.org/project/snps/\n"
+                f'# Generated at {datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S")} UTC\n'
             )
         else:
             s = ""
